# HSLU
#
# Created by Thomas Koller on 7/22/2020
#

# new base package for main classes
name = 'game' \
     ''
